package model

type DistributeFeedFormulaRequest struct {
	PastureId int64          `json:"pasture_id"`
	Body      []*FeedFormula `json:"body"`
}

type PastureResponse struct {
	Code int32       `json:"code"`
	Msg  string      `json:"msg"`
	Data interface{} `json:"data"`
}

type DashboardAccuracyRequest struct {
	CattleParentCategoryId int32  `json:"cattle_parent_category_id,omitempty"`
	FeedFormulaId          int32  `json:"feed_formula_id"`
	StartDate              string `json:"start_date"`
	EndDate                string `json:"end_date"`
	PastureId              int32  `json:"pasture_id"`
}

type FeedFormulaIsModifyRequest struct {
	PastureId     int64 `json:"pasture_id"`
	FeedFormulaId int64 `json:"feed_formula_id"`
	IsModify      int32 `json:"is_modify"`
}

type PastureAnalysisAccuracyResponse struct {
	Code int32                        `json:"code"`
	Msg  string                       `json:"msg"`
	Data *PastureAnalysisAccuracyData `json:"data"`
}

type PastureAnalysisAccuracyData struct {
	MixedFodderAccurateRatio    []*PastureAnalysisAccuracyDataValue `json:"mixed_fodder_accurate_ratio"`    // 混料准确率
	MixedFodderCorrectRatio     []*PastureAnalysisAccuracyDataValue `json:"mixed_fodder_correct_ratio"`     // 混料正确率
	SprinkleFodderAccurateRatio []*PastureAnalysisAccuracyDataValue `json:"sprinkle_fodder_accurate_ratio"` // 撒料准确率
	SprinkleFodderCorrectRatio  []*PastureAnalysisAccuracyDataValue `json:"sprinkle_fodder_correct_ratio"`  // 撒料正确率
}

type PastureAnalysisAccuracyDataValue struct {
	DayTime string  `json:"day_time"`
	Ratio   float64 `json:"ratio"`
}

type AccountDistribution struct {
	Account     string `json:"account"`
	UserName    string `json:"user_name"`
	Password    string `json:"password"`
	Phone       string `json:"phone"`
	PastureId   int32  `json:"pasture_id"`
	PastureName string `json:"pasture_name"`
	Address     string `json:"address"`
}

type CategoryRequest struct {
	PastureId  int32  `json:"pasture_id"`
	ParentId   int32  `json:"parent_id"`
	ParentName string `json:"parent_name"`
	Name       string `json:"name"`
	Number     string `json:"number"`
	IsShow     int32  `json:"is_show"`
	GroupId    int32  `json:"group_id"`
}

type CategoryDeleteRequest struct {
	PastureId int32 `json:"pasture_id"`
	GroupId   int32 `json:"group_id"`
	IsDelete  int32 `json:"is_delete"`
}

type FeedFormulaListRequest struct {
	PastureId int32 `json:"pasture_id"`
	Page      int32 `json:"page"`
	PageSize  int32 `json:"page_size"`
}

type FeedFormulaListResponse struct {
	Code int32            `json:"code"`
	Msg  string           `json:"msg"`
	Data *FeedFormulaData `json:"data"`
}

type FeedFormulaData struct {
	Total    int32           `json:"total"`
	Page     int32           `json:"page"`
	PageSize int32           `json:"page_size"`
	List     []*FeedTemplate `json:"list"`
}

type FeedTemplate struct {
	Id           int64   `xorm:"id"`
	PastureId    int64   `xorm:"pastureid"`
	TCode        string  `xorm:"tcode"`
	TName        string  `xorm:"tname"`
	TColor       string  `xorm:"tcolor"`
	CCid         int64   `xorm:"ccid"`
	CCName       string  `xorm:"ccname"`
	FTType       string  `xorm:"fttype"`
	FTTypeId     int32   `xorm:"fttypeid"`
	Source       string  `xorm:"source"`
	Remark       string  `xorm:"remark"`
	Enable       int32   `xorm:"enable"`
	Sort         int64   `xorm:"sort"`
	Owner        string  `xorm:"owner"`
	Weight       float64 `xorm:"weight"`
	DryWeight    float64 `xorm:"dryweight"`
	IsDelete     int32   `xorm:"isdelete"`
	Version      int64   `xorm:"version"`
	SaveTime     string  `xorm:"savetime"`
	IsIssue      int32   `xorm:"isissue"`
	IssueVersion int32   `xorm:"issueversion"`
	IssueId      int64   `xorm:"issueid"`
	Backup1      string  `xorm:"backup1"`
	Backup2      string  `xorm:"backup2"`
	IsModify     int32   `xorm:"is_modify"`
}

// MixedCategoryTmrNameParams tmr名称和混料类别
type MixedCategoryTmrNameParams struct {
	PastureId string `json:"pastureid"` //牧场id
	StartTime string `json:"startdate,omitempty"`
	EndTime   string `json:"enddate,omitempty"`
}
